<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://www.mergado.cz
 * @since      1.0.0
 *
 * @package    Mergado_Marketing_Pack
 * @subpackage Mergado_Marketing_Pack/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Mergado_Marketing_Pack
 * @subpackage Mergado_Marketing_Pack/includes
 * @author     Mergado technologies, s. r. o. <info@mergado.cz>
 */
class Mergado_Marketing_Pack
{

    /**
     * The loader that's responsible for maintaining and registering all hooks that power
     * the plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      Mergado_Marketing_Pack_Loader $loader Maintains and registers all hooks for the plugin.
     */
    protected $loader;

    /**
     * The unique identifier of this plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      string $plugin_name The string used to uniquely identify this plugin.
     */
    protected $plugin_name;

    /**
     * The current version of the plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      string $version The current version of the plugin.
     */
    protected $version;

    protected $headerExtra = '';

    /**
     * Define the core functionality of the plugin.
     *
     * Set the plugin name and the plugin version that can be used throughout the plugin.
     * Load the dependencies, define the locale, and set the hooks for the admin area and
     * the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function __construct()
    {
        if (defined('PLUGIN_VERSION')) {
            $this->version = PLUGIN_VERSION;
        } else {
            $this->version = '1.0.0';
        }
        $this->plugin_name = 'mergado-marketing-pack';

        $this->load_dependencies();
        $this->set_locale();
        $this->define_admin_hooks();
        $this->define_public_hooks();
    }

    /**
     * Load the required dependencies for this plugin.
     *
     * Include the following files that make up the plugin:
     *
     * - Mergado_Marketing_Pack_Loader. Orchestrates the hooks of the plugin.
     * - Mergado_Marketing_Pack_i18n. Defines internationalization functionality.
     * - Mergado_Marketing_Pack_Admin. Defines all hooks for the admin area.
     * - Mergado_Marketing_Pack_Public. Defines all hooks for the public side of the site.
     *
     * Create an instance of the loader which will be used to register the hooks
     * with WordPress.
     *
     * @since    1.0.0
     * @access   private
     */
    private function load_dependencies()
    {

        /**
         * The class responsible for orchestrating the actions and filters of the
         * core plugin.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-mergado-marketing-pack-loader.php';

        /**
         * The class responsible for defining internationalization functionality
         * of the plugin.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-mergado-marketing-pack-i18n.php';

        /**
         * The class responsible for defining all actions that occur in the admin area.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/class-mergado-marketing-pack-admin.php';

        /**
         * The class responsible for defining all actions that occur in the public-facing
         * side of the site.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'public/class-mergado-marketing-pack-public.php';

        $this->loader = new Mergado_Marketing_Pack_Loader();
    }

    /**
     * Define the locale for this plugin for internationalization.
     *
     * Uses the Mergado_Marketing_Pack_i18n class in order to set the domain and to register the hook
     * with WordPress.
     *
     * @since    1.0.0
     * @access   private
     */
    private function set_locale()
    {

        $plugin_i18n = new Mergado_Marketing_Pack_i18n();

        $this->loader->add_action('plugins_loaded', $plugin_i18n, 'load_plugin_textdomain');
    }

    /**
     * Register all of the hooks related to the admin area functionality
     * of the plugin.
     *
     * @since    1.0.0
     * @access   private
     */
    private function define_admin_hooks()
    {

        $plugin_admin = new Mergado_Marketing_Pack_Admin($this->get_plugin_name(), $this->get_version());

        $this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_styles');
        $this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts');
    }

    /**
     * Register all of the hooks related to the public-facing functionality
     * of the plugin.
     *
     * @since    1.0.0
     * @access   private
     */
    private function define_public_hooks()
    {

        $plugin_public = new Mergado_Marketing_Pack_Public($this->get_plugin_name(), $this->get_version());

        $this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_styles');
        $this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_scripts');
    }

    /**
     * Run the loader to execute all of the hooks with WordPress.
     *
     * @since    1.0.0
     */
    public function run()
    {
        $this->loader->run();
        $this->processFrontView();
    }

    /**
     * The name of the plugin used to uniquely identify it within the context of
     * WordPress and to define internationalization functionality.
     *
     * @since     1.0.0
     * @return    string    The name of the plugin.
     */
    public function get_plugin_name()
    {
        return $this->plugin_name;
    }

    /**
     * The reference to the class that orchestrates the hooks with the plugin.
     *
     * @since     1.0.0
     * @return    Mergado_Marketing_Pack_Loader    Orchestrates the hooks of the plugin.
     */
    public function get_loader()
    {
        return $this->loader;
    }

    /**
     * Retrieve the version number of the plugin.
     *
     * @since     1.0.0
     * @return    string    The version number of the plugin.
     */
    public function get_version()
    {
        return $this->version;
    }

    public function processFrontView()
    {
        add_action('wp_head', array($this, 'glamiPixel'), 98);
        add_action('wp_footer', array($this, 'mergadoFooterSetup'), 98);
        add_action('woocommerce_add_to_cart', array($this, 'glamiPixelAddToCart'), 99);
    }

    public function glamiPixel()
    {
        global $wp;

        $active = get_option('glami-form-active', 0);
        $code = get_option('glami-form-pixel', '');
        if($active == 1 && $code != "") {
            ?>
            <script>
                (function(f, a, s, h, i, o, n) {f['GlamiTrackerObject'] = i;
                    f[i]=f[i]||function(){(f[i].q=f[i].q||[]).push(arguments)};o=a.createElement(s),
                        n=a.getElementsByTagName(s)[0];o.async=1;o.src=h;n.parentNode.insertBefore(o,n)
                })(window, document, 'script', '//www.glami.cz/js/compiled/pt.js', 'glami');

                glami('create', '<?php echo $code; ?>', 'cz');
                glami('track', 'PageView');

                <?php
                    // CATEGORY PAGE
                    if(is_product_category()) :
                        $category = get_queried_object();
                        $products_tmp = wc_get_products(array('category' => array($category->slug)));
                        $products = array();

                        foreach ($products_tmp as $product) {
                            $products['ids'][] = "'" . $product->id . "'";
                            $products['name'][] = "'". $product->name . "'";
                        }
                ?>
                    glami('track', 'ViewContent', {
                        content_type: 'category',
                        item_ids: [<?php echo implode(',', $products['ids']); ?>],
                        product_names: [<?php echo implode(',', $products['name']); ?>],
                        category_id: '<?php echo $category->term_id; ?>',
                        category_text: '<?php echo $category->name; ?>'
                    });
                <?php endif; ?>


                <?php
                // PRODUCT PAGE
                if(is_product()) :
                $product = get_queried_object();
                ?>
                glami('track', 'ViewContent', {
                    content_type: 'product',
                    item_ids: ['<?php echo $product->ID; ?>'],
                    product_names: ['<?php echo $product->post_title; ?>'],
                });
                <?php endif; ?>
            </script>
            <?php

            if (is_wc_endpoint_url('order-received')) {
                $orderId = intval(str_replace('checkout/order-received/', '', $wp->request));
                $this->glamiPixelPurchased($orderId);
            }

            echo $this->headerExtra;
        }
    }

    public function glamiPixelAddToCart()
    {
        $active = get_option('glami-form-active', 0);
        $code = get_option('glami-form-pixel', '');
        if($active == 1 && $code != "") {
            if (isset($_POST['add-to-cart'])) {
                $product = wc_get_product($_POST['add-to-cart']);
                ob_start();
                ?>
                <script>
                glami('track', 'AddToCart', {
                    item_ids: ['<?php echo $product->get_id(); ?>'],
                    product_names: ['<?php echo $product->get_name(); ?>'],
                    value: <?php echo $product->price; ?>,
                    currency: '<?php echo get_woocommerce_currency(); ?>'
                });
                </script>
                <?php

                $this->headerExtra .= ob_get_contents();
                ob_end_clean();
            }
        }
    }

    public function glamiPixelPurchased($orderId)
    {
        $active = get_option('glami-form-active', 0);
        $code = get_option('glami-form-pixel', '');

        if($active == 1 && $code != "") {
            $order = wc_get_order($orderId );
            $products_tmp = $order->get_items();

            $products = array();
            foreach ($products_tmp as $product) {
                $products['ids'][] = "'" . $product->get_id() . "'";
                $products['name'][] = "'". $product->get_name() . "'";
            }

            ob_start();
            ?>
            <script>
            glami('track', 'Purchase', {
                item_ids: [<?php echo implode(',', $products['ids']); ?>],
                product_names: [<?php echo implode(',', $products['name']); ?>],
                value: <?php echo $order->total; ?>,
                currency: '<?php echo get_woocommerce_currency(); ?>',
                transaction_id: '<?php echo $orderId; ?>'
            });
            </script>
            <?php

            $this->headerExtra .= ob_get_contents();
            ob_end_clean();
        }
    }

    public function mergadoFooterSetup()
    {
        echo '<div id="mergadoSetup" data-currency="'. get_woocommerce_currency() .'"></div>';
    }

}
